@@ -248,6 +248,12 @@ sub is_version {
     return 0;
 }
 
+sub param {
+    my $self = shift;
+    $self->{body_params} ||= $self->body_params;
+    return $self->{body_params}->param(@_);
+}
+
 # Please don't eat me! I have a wife and kids. Eat them!
 sub parse {
     my $self = shift;
@@ -549,6 +555,10 @@ Returns a L<Mojo::Parameters> object, containing POST parameters.
 
     my $is_version = $message->is_version('1.1);
 
+=head2 C<param>
+
+    my $param = $message->param('foo');
+
 =head2 C<parse>
 
     $message = $message->parse('HTTP/1.1 200 OK...');
